==> qtjambi-uic-5.15.18-sources.jar: io/qt/uic/ui4/DomDateTime.java <==
package io.qt.uic.ui4;

import io.qt.*;


/**
 * @hidden
 * <p>Java wrapper for Qt class <code>DomDateTime</code></p>
 */
public class DomDateTime extends QtObject
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    
    /**
     * <p>See <code>DomDateTime::<wbr/>DomDateTime()</code></p>
     */
    public DomDateTime(){
        super((QPrivateConstructor)null);
        initialize_native(this);
    }
    
    private native static void initialize_native(DomDateTime instance);
    
    /**
     * <p>See <code>DomDateTime::<wbr/>clearElementDay()</code></p>
     */
    @QtUninvokable
    public final void clearElementDay(){
        clearElementDay_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native void clearElementDay_native(long __this__nativeId);
    
    /**
     * <p>See <code>DomDateTime::<wbr/>clearElementHour()</code></p>
     */
    @QtUninvokable
    public final void clearElementHour(){
        clearElementHour_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native void clearElementHour_native(long __this__nativeId);
    
    /**
     * <p>See <code>DomDateTime::<wbr/>clearElementMinute()</code></p>
     */
    @QtUninvokable
    public final void clearElementMinute(){
        clearElementMinute_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native void clearElementMinute_native(long __this__nativeId);
    
    /**
     * <p>See <code>DomDateTime::<wbr/>clearElementMonth()</code></p>
     */
    @QtUninvokable
    public final void clearElementMonth(){
        clearElementMonth_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native void clearElementMonth_native(long __this__nativeId);
    
    /**
     * <p>See <code>DomDateTime::<wbr/>clearElementSecond()</code></p>
     */
    @QtUninvokable
    public final void clearElementSecond(){
        clearElementSecond_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native void clearElementSecond_native(long __this__nativeId);
    
    /**
     * <p>See <code>DomDateTime::<wbr/>clearElementYear()</code></p>
     */
    @QtUninvokable
    public final void clearElementYear(){
        clearElementYear_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native void clearElementYear_native(long __this__nativeId);
    
    /**
     * <p>See <code>DomDateTime::<wbr/>elementDay()const</code></p>
     */
    @QtUninvokable
    public final int elementDay(){
        return elementDay_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native int elementDay_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code>DomDateTime::<wbr/>elementHour()const</code></p>
     */
    @QtUninvokable
    public final int elementHour(){
        return elementHour_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native int elementHour_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code>DomDateTime::<wbr/>elementMinute()const</code></p>
     */
    @QtUninvokable
    public final int elementMinute(){
        return elementMinute_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native int elementMinute_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code>DomDateTime::<wbr/>elementMonth()const</code></p>
     */
    @QtUninvokable
    public final int elementMonth(){
        return elementMonth_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native int elementMonth_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code>DomDateTime::<wbr/>elementSecond()const</code></p>
     */
    @QtUninvokable
    public final int elementSecond(){
        return elementSecond_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native int elementSecond_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code>DomDateTime::<wbr/>elementYear()const</code></p>
     */
    @QtUninvokable
    public final int elementYear(){
        return elementYear_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native int elementYear_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code>DomDateTime::<wbr/>hasElementDay()const</code></p>
     */
    @QtUninvokable
    public final boolean hasElementDay(){
        return hasElementDay_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native boolean hasElementDay_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code>DomDateTime::<wbr/>hasElementHour()const</code></p>
     */
    @QtUninvokable
    public final boolean hasElementHour(){
        return hasElementHour_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native boolean hasElementHour_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code>DomDateTime::<wbr/>hasElementMinute()const</code></p>
     */
    @QtUninvokable
    public final boolean hasElementMinute(){
        return hasElementMinute_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native boolean hasElementMinute_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code>DomDateTime::<wbr/>hasElementMonth()const</code></p>
     */
    @QtUninvokable
    public final boolean hasElementMonth(){
        return hasElementMonth_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native boolean hasElementMonth_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code>DomDateTime::<wbr/>hasElementSecond()const</code></p>
     */
    @QtUninvokable
    public final boolean hasElementSecond(){
        return hasElementSecond_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native boolean hasElementSecond_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code>DomDateTime::<wbr/>hasElementYear()const</code></p>
     */
    @QtUninvokable
    public final boolean hasElementYear(){
        return hasElementYear_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native boolean hasElementYear_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code>DomDateTime::<wbr/>read(QXmlStreamReader&amp;)</code></p>
     */
    @QtUninvokable
    public final void read(io.qt.core.@StrictNonNull QXmlStreamReader reader){
        java.util.Objects.requireNonNull(reader, "Argument 'reader': null not expected.");
        read_native_ref_QXmlStreamReader(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(reader));
    }
    
    @QtUninvokable
    private native void read_native_ref_QXmlStreamReader(long __this__nativeId, long reader);
    
    /**
     * <p>See <code>DomDateTime::<wbr/>setElementDay(int)</code></p>
     */
    @QtUninvokable
    public final void setElementDay(int a){
        setElementDay_native_int(QtJambi_LibraryUtilities.internal.nativeId(this), a);
    }
    
    @QtUninvokable
    private native void setElementDay_native_int(long __this__nativeId, int a);
    
    /**
     * <p>See <code>DomDateTime::<wbr/>setElementHour(int)</code></p>
     */
    @QtUninvokable
    public final void setElementHour(int a){
        setElementHour_native_int(QtJambi_LibraryUtilities.internal.nativeId(this), a);
    }
    
    @QtUninvokable
    private native void setElementHour_native_int(long __this__nativeId, int a);
    
    /**
     * <p>See <code>DomDateTime::<wbr/>setElementMinute(int)</code></p>
     */
    @QtUninvokable
    public final void setElementMinute(int a){
        setElementMinute_native_int(QtJambi_LibraryUtilities.internal.nativeId(this), a);
    }
    
    @QtUninvokable
    private native void setElementMinute_native_int(long __this__nativeId, int a);
    
    /**
     * <p>See <code>DomDateTime::<wbr/>setElementMonth(int)</code></p>
     */
    @QtUninvokable
    public final void setElementMonth(int a){
        setElementMonth_native_int(QtJambi_LibraryUtilities.internal.nativeId(this), a);
    }
    
    @QtUninvokable
    private native void setElementMonth_native_int(long __this__nativeId, int a);
    
    /**
     * <p>See <code>DomDateTime::<wbr/>setElementSecond(int)</code></p>
     */
    @QtUninvokable
    public final void setElementSecond(int a){
        setElementSecond_native_int(QtJambi_LibraryUtilities.internal.nativeId(this), a);
    }
    
    @QtUninvokable
    private native void setElementSecond_native_int(long __this__nativeId, int a);
    
    /**
     * <p>See <code>DomDateTime::<wbr/>setElementYear(int)</code></p>
     */
    @QtUninvokable
    public final void setElementYear(int a){
        setElementYear_native_int(QtJambi_LibraryUtilities.internal.nativeId(this), a);
    }
    
    @QtUninvokable
    private native void setElementYear_native_int(long __this__nativeId, int a);
    
    /**
     * <p>See <code>DomDateTime::<wbr/>write(QXmlStreamWriter&amp;,<wbr/>QString)const</code></p>
     */
    @QtUninvokable
    public final void write(io.qt.core.@StrictNonNull QXmlStreamWriter writer, java.lang.@NonNull String tagName){
        java.util.Objects.requireNonNull(writer, "Argument 'writer': null not expected.");
        write_native_ref_QXmlStreamWriter_cref_QString_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(writer), tagName);
    }
    
    @QtUninvokable
    private native void write_native_ref_QXmlStreamWriter_cref_QString_constfct(long __this__nativeId, long writer, java.lang.String tagName);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     * @hidden
     */
    @NativeAccess
    protected DomDateTime(QPrivateConstructor p) { super(p); } 
    
    
    /**
     * <p>Overloaded function for {@link #write(io.qt.core.QXmlStreamWriter, java.lang.String)}
     *  with <code>tagName = (String)null</code>.</p>
     */
    @QtUninvokable
    public final void write(io.qt.core.@StrictNonNull QXmlStreamWriter writer) {
        write(writer, (String)null);
    }
}

==> qtjambi-uic-6.3.3-sources.jar: io/qt/uic/ui4/DomDateTime.java <==
package io.qt.uic.ui4;


/**
 * <p>Java wrapper for Qt class DomDateTime</p>
 */
public class DomDateTime extends io.qt.QtObject
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    
    public DomDateTime(){
        super((QPrivateConstructor)null);
        initialize_native(this);
    }
    
    private native static void initialize_native(DomDateTime instance);
    
    @io.qt.QtUninvokable
    public final void clearElementDay(){
        clearElementDay_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native void clearElementDay_native(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final void clearElementHour(){
        clearElementHour_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native void clearElementHour_native(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final void clearElementMinute(){
        clearElementMinute_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native void clearElementMinute_native(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final void clearElementMonth(){
        clearElementMonth_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native void clearElementMonth_native(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final void clearElementSecond(){
        clearElementSecond_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native void clearElementSecond_native(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final void clearElementYear(){
        clearElementYear_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native void clearElementYear_native(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final int elementDay(){
        return elementDay_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native int elementDay_native_constfct(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final int elementHour(){
        return elementHour_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native int elementHour_native_constfct(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final int elementMinute(){
        return elementMinute_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native int elementMinute_native_constfct(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final int elementMonth(){
        return elementMonth_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native int elementMonth_native_constfct(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final int elementSecond(){
        return elementSecond_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native int elementSecond_native_constfct(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final int elementYear(){
        return elementYear_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native int elementYear_native_constfct(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final boolean hasElementDay(){
        return hasElementDay_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native boolean hasElementDay_native_constfct(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final boolean hasElementHour(){
        return hasElementHour_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native boolean hasElementHour_native_constfct(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final boolean hasElementMinute(){
        return hasElementMinute_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native boolean hasElementMinute_native_constfct(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final boolean hasElementMonth(){
        return hasElementMonth_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native boolean hasElementMonth_native_constfct(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final boolean hasElementSecond(){
        return hasElementSecond_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native boolean hasElementSecond_native_constfct(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final boolean hasElementYear(){
        return hasElementYear_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native boolean hasElementYear_native_constfct(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final void read(io.qt.core.QXmlStreamReader reader){
        java.util.Objects.requireNonNull(reader, "Argument 'reader': null not expected.");
        read_native_ref_QXmlStreamReader(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(reader));
    }
    
    @io.qt.QtUninvokable
    private native void read_native_ref_QXmlStreamReader(long __this__nativeId, long reader);
    
    @io.qt.QtUninvokable
    public final void setElementDay(int a){
        setElementDay_native_int(QtJambi_LibraryUtilities.internal.nativeId(this), a);
    }
    
    @io.qt.QtUninvokable
    private native void setElementDay_native_int(long __this__nativeId, int a);
    
    @io.qt.QtUninvokable
    public final void setElementHour(int a){
        setElementHour_native_int(QtJambi_LibraryUtilities.internal.nativeId(this), a);
    }
    
    @io.qt.QtUninvokable
    private native void setElementHour_native_int(long __this__nativeId, int a);
    
    @io.qt.QtUninvokable
    public final void setElementMinute(int a){
        setElementMinute_native_int(QtJambi_LibraryUtilities.internal.nativeId(this), a);
    }
    
    @io.qt.QtUninvokable
    private native void setElementMinute_native_int(long __this__nativeId, int a);
    
    @io.qt.QtUninvokable
    public final void setElementMonth(int a){
        setElementMonth_native_int(QtJambi_LibraryUtilities.internal.nativeId(this), a);
    }
    
    @io.qt.QtUninvokable
    private native void setElementMonth_native_int(long __this__nativeId, int a);
    
    @io.qt.QtUninvokable
    public final void setElementSecond(int a){
        setElementSecond_native_int(QtJambi_LibraryUtilities.internal.nativeId(this), a);
    }
    
    @io.qt.QtUninvokable
    private native void setElementSecond_native_int(long __this__nativeId, int a);
    
    @io.qt.QtUninvokable
    public final void setElementYear(int a){
        setElementYear_native_int(QtJambi_LibraryUtilities.internal.nativeId(this), a);
    }
    
    @io.qt.QtUninvokable
    private native void setElementYear_native_int(long __this__nativeId, int a);
    
    /**
     * <p>Overloaded function for {@link #write(io.qt.core.QXmlStreamWriter, java.lang.String)}
     *  with <code>tagName = ""</code>.</p>
     */
    @io.qt.QtUninvokable
    public final void write(io.qt.core.QXmlStreamWriter writer) {
        write(writer, "");
    }
    
    @io.qt.QtUninvokable
    public final void write(io.qt.core.QXmlStreamWriter writer, java.lang.String tagName){
        java.util.Objects.requireNonNull(writer, "Argument 'writer': null not expected.");
        write_native_ref_QXmlStreamWriter_cref_QString_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(writer), tagName);
    }
    
    @io.qt.QtUninvokable
    private native void write_native_ref_QXmlStreamWriter_cref_QString_constfct(long __this__nativeId, long writer, java.lang.String tagName);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected DomDateTime(QPrivateConstructor p) { super(p); } 
    
}
